# LOBMP
Limit Order Book Message Processor is a Python package designed to transform raw lseg(aka Refinitiv) high frequency trading data into convenient formats such as parquet.

!!! warning "Package under development"
    Please keep in mind this a package under development, so bugs are expected and functionality is not guaranteed to be 100% correct.


If you want to quickstart using `lobmp` please see the [quickstart](quickstart) page.
